.. odoo_rpc_client documentation master file, created by
   sphinx-quickstart on Fri Apr 25 11:05:31 2014.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

Welcome to odoo_rpc_client's documentation!
=========================================

Contents:

.. toctree::
   :maxdepth: 2

   intro.rst
   module_ref/modules.rst



Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`

